@@ -27,12 +27,12 @@
 #include "listjob.h"
 #include "kcoredirlister.h"
 #include "scheduler.h"
-#include "kdirwatch.h"
+#include <KDirWatch>
 #include "kprotocolmanager.h"
 #include <kdirnotify.h>
 #include "../pathhelpers_p.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <kio/jobuidelegatefactory.h>
 
 #include <QTimer>
@@ -475,6 +475,11 @@ void DeleteJobPrivate::deleteNextDir()
     if (m_reportTimer != nullptr) {
         m_reportTimer->stop();
     }
+    // display final numbers
+    q->setProcessedAmount(KJob::Directories, m_processedDirs);
+    q->setProcessedAmount(KJob::Files, m_processedFiles);
+    q->emitPercent(m_processedFiles + m_processedDirs, m_totalFilesDirs);
+
     q->emitResult();
 }
 
