@@ -24,16 +24,17 @@
 
 #include "ktcpsocket.h"
 #include "ksslerroruidata_p.h"
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
 #include <QDebug>
-#include <qstandardpaths.h>
+#include <QStandardPaths>
 #include <QFile>
 #include <QDir>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
+#include <QSslConfiguration>
 
 #include "kssld_interface.h"
 
@@ -112,16 +113,19 @@ bool KSslCertificateRule::isRejected() const
     return d->isRejected;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 bool KSslCertificateRule::isErrorIgnored(KSslError::Error error) const
 {
     return d->ignoredErrors.contains(KSslErrorPrivate::errorFromKSslError(error));
 }
+#endif
 
 bool KSslCertificateRule::isErrorIgnored(QSslError::SslError error) const
 {
     return d->ignoredErrors.contains(error);
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 void KSslCertificateRule::setIgnoredErrors(const QList<KSslError::Error> &errors)
 {
     d->ignoredErrors.clear();
@@ -133,7 +137,9 @@ void KSslCertificateRule::setIgnoredErrors(const QList<KSslError::Error> &errors
         }
     }
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 void KSslCertificateRule::setIgnoredErrors(const QList<KSslError> &errors)
 {
     QList<KSslError::Error> el;
@@ -143,6 +149,7 @@ void KSslCertificateRule::setIgnoredErrors(const QList<KSslError> &errors)
     }
     setIgnoredErrors(el);
 }
+#endif
 
 void KSslCertificateRule::setIgnoredErrors(const QList<QSslError> &errors)
 {
@@ -164,16 +171,23 @@ void KSslCertificateRule::setIgnoredErrors(const QList<QSslError::SslError> &err
     }
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 QList<KSslError::Error> KSslCertificateRule::ignoredErrors() const
 {
-    // TODO KF6: return d->ignoredErrors
-    // return d->ignoredErrors;
+    // KF6: replace by QList<QSslError::SslError> below
     QList<KSslError::Error> errors;
     errors.reserve(d->ignoredErrors.size());
     std::transform(d->ignoredErrors.cbegin(), d->ignoredErrors.cend(), std::back_inserter(errors), KSslErrorPrivate::errorFromQSslError);
     return errors;
 }
+#else
+QList<QSslError::SslError> KSslCertificateRule::ignoredErrors() const
+{
+    return d->ignoredErrors;
+}
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 QList<KSslError::Error> KSslCertificateRule::filterErrors(const QList<KSslError::Error> &errors) const
 {
     QList<KSslError::Error> ret;
@@ -184,7 +198,9 @@ QList<KSslError::Error> KSslCertificateRule::filterErrors(const QList<KSslError:
     }
     return ret;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 QList<KSslError> KSslCertificateRule::filterErrors(const QList<KSslError> &errors) const
 {
     QList<KSslError> ret;
@@ -195,6 +211,7 @@ QList<KSslError> KSslCertificateRule::filterErrors(const QList<KSslError> &error
     }
     return ret;
 }
+#endif
 
 QList<QSslError> KSslCertificateRule::filterErrors(const QList<QSslError> &errors) const
 {
@@ -248,8 +265,13 @@ void KSslCertificateManagerPrivate::loadDefaultCaCertificates()
     KConfig config(QStringLiteral("ksslcablacklist"), KConfig::SimpleConfig);
     KConfigGroup group = config.group("Blacklist of CA Certificates");
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    certs.append(QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
+                                           QSslCertificate::PatternSyntax::Wildcard));
+#else
     certs.append(QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
                                            QRegExp::Wildcard));
+#endif
     for (const QSslCertificate &cert : qAsConst(certs)) {
         const QByteArray digest = cert.digest().toHex();
         if (!group.hasKey(digest.constData())) {
@@ -405,8 +427,13 @@ QList<KSslCaCertificate> KSslCertificateManagerPrivate::allCertificates() const
         ret += KSslCaCertificate(cert, KSslCaCertificate::SystemStore, false);
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    const QList<QSslCertificate> userList = QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
+                                                                   QSslCertificate::PatternSyntax::Wildcard);
+#else
     const QList<QSslCertificate> userList = QSslCertificate::fromPath(userCertDir + QLatin1Char('*'), QSsl::Pem,
                                                                    QRegExp::Wildcard);
+#endif
     for (const QSslCertificate &cert : userList) {
         ret += KSslCaCertificate(cert, KSslCaCertificate::UserStore, false);
     }
@@ -501,6 +528,7 @@ QList<QSslCertificate> KSslCertificateManager::caCertificates() const
     return d->defaultCaCertificates;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 //static
 QList<KSslError> KSslCertificateManager::nonIgnorableErrors(const QList<KSslError> &errors)
 {
@@ -511,7 +539,9 @@ QList<KSslError> KSslCertificateManager::nonIgnorableErrors(const QList<KSslErro
     });
     return ret;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 64)
 //static
 QList<KSslError::Error> KSslCertificateManager::nonIgnorableErrors(const QList<KSslError::Error> &errors)
 {
@@ -522,6 +552,7 @@ QList<KSslError::Error> KSslCertificateManager::nonIgnorableErrors(const QList<K
     });
     return ret;
 }
+#endif
 
 QList<QSslError> KSslCertificateManager::nonIgnorableErrors(const QList<QSslError> &errors)
 {
