@@ -10,22 +10,20 @@
 
 #include "kimagefilepreview.h"
 
-#include <QLayout>
 #include <QLabel>
 #include <QPainter>
-#include <QComboBox>
 #include <QCheckBox>
 #include <QResizeEvent>
-#include <QTimer>
 #include <QTimeLine>
+#include <QVBoxLayout>
+#include <QStyle>
 
-#include <kconfig.h>
-#include <kiconloader.h>
-#include <QDebug>
-#include <klocalizedstring.h>
+#include <KConfig>
+#include <KIconLoader>
+#include <KLocalizedString>
 #include <kfileitem.h>
 #include <kio/previewjob.h>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 /**** KImageFilePreview ****/
 
@@ -69,7 +67,7 @@ KImageFilePreview::KImageFilePreview(QWidget *parent)
     : KPreviewWidgetBase(parent), d(new KImageFilePreviewPrivate)
 {
     QVBoxLayout *vb = new QVBoxLayout(this);
-    vb->setMargin(0);
+    vb->setContentsMargins(0, 0, 0, 0);
 
     d->imageLabel = new QLabel(this);
     d->imageLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
@@ -199,8 +197,8 @@ void KImageFilePreview::KImageFilePreviewPrivate::_k_slotFailed(const KFileItem
     if (item.isDir()) {
         imageLabel->clear();
     } else if (item.url() == currentURL) // should always be the case
-        imageLabel->setPixmap(SmallIcon(QStringLiteral("image-missing"), KIconLoader::SizeLarge,
-                                        KIconLoader::DisabledState));
+        imageLabel->setPixmap(QIcon::fromTheme(QStringLiteral("image-missing"))
+            .pixmap(KIconLoader::SizeLarge, QIcon::Disabled));
 }
 
 void KImageFilePreview::KImageFilePreviewPrivate::_k_slotResult(KJob *job)
