@@ -25,23 +25,25 @@
 #include <KIO/ApplicationLauncherJob>
 #include "krun.h"
 #include "kautomount.h"
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <kdirnotify.h>
 #include <KDialogJobUiDelegate>
 #include <kmountpoint.h>
 
-#include <kdesktopfile.h>
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
-#include <kservice.h>
+#include <KDesktopFile>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KService>
 
 #include <QDBusInterface>
 #include <QDBusReply>
 
 enum BuiltinServiceType { ST_MOUNT = 0x0E1B05B0, ST_UNMOUNT = 0x0E1B05B1 }; // random numbers
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 static bool runFSDevice(const QUrl &_url, const KDesktopFile &cfg, const QByteArray &asn);
 static bool runLink(const QUrl &_url, const KDesktopFile &cfg, const QByteArray &asn);
+#endif
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(5, 71)
 bool KDesktopFileActions::run(const QUrl &u, bool _is_local)
